#
# spec file for package libvirt-cim (Version 0.5.14)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if 0%{?suse_version} > 1140 || 0%{?fedora_version} > 14
%define has_systemd 1
%else
%define has_systemd 0
%endif

Name:           libvirt-cim

Url:            http://libvirt.org/CIM/
License:        LGPL-2.1+
Group:          System/Management
Version:        0.6.3
Release:        15.4
Summary:        CMPI-based CIM provider implementing DMTF SVPC model
Source:         %{name}-%{version}.tar.bz2
Source1:        libvirt-cim-rpmlintrc
Source2:        README.SUSE
Patch0:         provider-reg.patch
Patch1:         automake.patch
Patch2:         libvirt-cim-0.6.3-fix-bashisms.patch
Patch3:         f6b7eeaf.patch
Patch4:         memory_leaks.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  automake
BuildRequires:  autoconf
BuildRequires:  e2fsprogs-devel
BuildRequires:  libcmpiutil-devel > 0.5.4
BuildRequires:  libtool
BuildRequires:  libuuid-devel
BuildRequires:  libvirt-devel >= 0.3.2
BuildRequires:  libxml2-devel
BuildRequires:  sblim-cmpi-devel
BuildRequires:  sblim-sfcb
%if 0%{?has_systemd}
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%endif
# the %pre/%post scripts are sfcb specific currently
Requires:       sblim-sfcb
Requires:       libxml2 >= 2.6.0
Requires:       cim-schema >= 2.17
Requires:       unzip
%if 0%{?suse_version} >= 1140
%if 0%{?has_systemd} == 0
Requires:       sysvinit-tools
%endif
%endif
Provides:       xen-cim-cmpi = 0.2.0
Obsoletes:      xen-cim-cmpi < 0.2.0

%description
Libvirt-cim is a CMPI CIM provider that implements the DMTF SVPC
virtualization model. The goal is to support most of the features
exported by libvirt itself, enabling management of multiple platforms
with a single provider.



Authors:
--------
    Dan Smith <danms@us.ibm.com>

%define REGISTRATION %{_datadir}/%{name}/*.registration
%define SCHEMA %{_datadir}/%{name}/*.mof
%define INTEROP_REG %{_datadir}/%{name}/{RegisteredProfile,ElementConformsToProfile,ReferencedProfile}.registration
%define INTEROP_MOF %{_datadir}/%{name}/{ComputerSystem,HostSystem,RegisteredProfile,DiskPool,MemoryPool,NetPool,ProcessorPool,VSMigrationService,ElementConformsToProfile,ReferencedProfile,AllocationCapabilities}.mof
%define CIMV2_REG %{_datadir}/%{name}/{HostedResourcePool,ElementCapabilities,HostedService,HostedDependency,ElementConformsToProfile,HostedAccessPoint}.registration
%define CIMV2_MOF %{_datadir}/%{name}/{HostedResourcePool,ElementCapabilities,HostedService,HostedDependency,RegisteredProfile,ComputerSystem,ElementConformsToProfile,HostedAccessPoint}.mof

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
chmod -x src/* libxkutil/* schema/* README doc/* base_schema/README*
chmod +X src/* libxkutil/* schema/*

%build
autoreconf -i -f
%configure --disable-werror --disable-static
make %{?_smp_mflags} DOCS_DIR=%{_docdir}/%{name} HTML_DIR=%{_docdir}/%{name}

%install
%if 0%{?suse_version}
%make_install DOCS_DIR=%{_docdir}/%{name} HTML_DIR=%{_docdir}/%{name}
install -m 644 %{S:2} $RPM_BUILD_ROOT%{_docdir}/%{name}
%else
make install DESTDIR=$RPM_BUILD_ROOT DOCS_DIR=%{_docdir}/%{name}-%{version} HTML_DIR=%{_docdir}/%{name}-%{version}
install -m 644 %{S:2} $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
%endif
%{__rm} -f $RPM_BUILD_ROOT%{_libdir}/*.{a,la}
%{__rm} -f $RPM_BUILD_ROOT%{_libdir}/cmpi/*.{a,la}
%{__rm} -f $RPM_BUILD_ROOT%{_libdir}/libxkutil.so
#%{__rm} -rf $RPM_BUILD_ROOT%{_docdir}/%{name}
#%{__rm} -f $RPM_BUILD_ROOT%{_datadir}/%{name}/install_base_schema.sh
#%{__rm} -f $RPM_BUILD_ROOT%{_datadir}/%{name}/cimv216-interop_mof
#%{__rm} -f $RPM_BUILD_ROOT%{_datadir}/%{name}/cimv216Experimental-MOFs.zip
#%{__rm} -f $RPM_BUILD_ROOT%{_datadir}/%{name}/fix_schema.patch
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/libvirt/cim

%pre
# unregister current providers on upgrade only
if [ $1 -eq 2 ]; then
%{_datadir}/%{name}/provider-register.sh -d -t sfcb \
	-n root/virt \
	-r %{REGISTRATION} -m %{SCHEMA} >/dev/null 2>&1 || true
fi

%post
/sbin/ldconfig
%{_datadir}/%{name}/install_base_schema.sh %{_datadir}/%{name}
# Register libvirt-cim on the sfcb's providers list
%{_datadir}/%{name}/provider-register.sh -t sfcb \
        -n root/virt \
        -r %{REGISTRATION} -m %{SCHEMA} >/dev/null 2>&1 || true
# Register some of our providers under other namespaces too? ok.
%{_datadir}/%{name}/provider-register.sh -t sfcb \
        -n root/interop \
        -r %{INTEROP_REG} -m %{INTEROP_MOF} -v >/dev/null 2>&1 || true
%{_datadir}/%{name}/provider-register.sh -t sfcb \
        -n root/cimv2\
        -r %{CIMV2_REG} -m %{CIMV2_MOF} -v >/dev/null 2>&1 || true
# Restart the sfcb to update its providers list
if test -x /usr/sbin/sfcbd ; then
%if 0%{?has_systemd}
  systemctl try-restart sblim-sfcb.service >/dev/null 2>&1 || :
%else
  /etc/init.d/sfcb restart
%endif
fi

%preun
# unregister our providers only on uninstall
if [ $1 -eq 0 ]; then
%{_datadir}/%{name}/provider-register.sh -d -t sfcb \
	-n root/virt \
	-r %{REGISTRATION} -m %{SCHEMA} >/dev/null 2>&1 || true
fi

%postun
/sbin/ldconfig
# Restart the sfcb to update its providers list
if test -x /usr/sbin/sfcbd ; then
%if 0%{?has_systemd}
  systemctl try-restart sblim-sfcb.service >/dev/null 2>&1 || :
%else
  /etc/init.d/sfcb restart
%endif
fi

%files
%defattr(-, root, root)
%dir %{_datadir}/%{name}
%config(noreplace) %{_sysconfdir}/libvirt-cim.conf
%{_libdir}/lib*.so*
%{_libdir}/cmpi/lib*.so*
%{_datadir}/%{name}/*.sh
%{_datadir}/%{name}/*.mof
%{_datadir}/%{name}/*.registration
%{_datadir}/%{name}/cim_schema_*-MOFs.zip
%{_datadir}/%{name}/cimv*-cimv2_mof
%{_datadir}/%{name}/cimv*-interop_mof
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/cim
%if 0%{?suse_version}
%doc %{_docdir}/%{name}
%doc COPYING README
%else
%doc %{_docdir}/%{name}-%{version}
%endif

%changelog
* Tue Aug 30 2022 Klaus Kämpf <kkaempf@suse.com>
- fix build
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Fri Jan 26 2018 adam.majer@suse.de
- use correct service name when restarting sblim-sfcb
- fix builds on RedHat
* Mon Jan 22 2018 adam.majer@suse.de
- don't unregister providers on upgrade (bnc#1076418)
- don't register root/virt namespace in %%post twice
- simplify %%pre
* Mon Jan  8 2018 adam.majer@suse.de
- f6b7eeaf.patch: backport memory leak fix
- memory_leaks.patch: fix asprintf related memory leaks
  (bnc#1002028)
* Sat Nov 29 2014 Led <ledest@gmail.com>
- fix bashisms in provider-register.sh script
- add patches:
  * libvirt-cim-0.6.3-fix-bashisms.patch
* Wed Oct 15 2014 jengelh@inai.de
- Enable parallel build and remove ancient specfile tags and sections
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Tue Feb 25 2014 kkaempf@suse.com
- add README.SUSE
* Mon Feb 17 2014 kkaempf@suse.com
- re-add COPYING and README to documentation
* Fri Feb 14 2014 jfehlig@suse.com
- Remove unneeded libvirt requirement
* Tue Feb  4 2014 jfehlig@suse.com
- Remove unneeded xen-devel build requirement
* Thu Jul 25 2013 kkaempf@suse.com
- Update to 0.6.3
  Improvements:
  - Add shareable property to disk (Xu Wang)
  - Update GPL (John Ferlan)
  - Improve support of nested KVM (Xu Wang)
  - make lldptool command and support output configurable (Xu Wang)
  - add an config option to disable KVM acceleration. (Xu Wang)
  - Update spec file with changes coming from Fedora (Daniel Veillard)
  Bug fixes:
  - Resolve Coverity complaint (John Ferlan)
  - CSI: Address two Coverity isssues (John Ferlan)
  - Fix kvm support check logic (Xu Wang)
  - Coverity: Resolve ARRAY_VS_SINGLETON - get_dev_paths() and callers
    (John Ferlan)
  - Coverity: Resolve USE_AFTER_FREE - lifecycle_thread_native() (John
    Ferlan)
  - Coverity: Resolve UNUSED_VALUE - system_xml() && mem_xml() (John
    Ferlan)
  - Coverity: Resolve UNINIT - vsss_delete_snapshot() (John Ferlan)
  - Coverity: Resolve REVERSE_INULL - lifecycle_thread_native() (John
    Ferlan)
  - Coverity: Resolve REVERSE_INULL - doms_to_xml() (John Ferlan)
  - Coverity: Resolve RESOURCE_LEAK - parse_os() (John Ferlan)
  - Coverity: Resolve NO_EFFECT - _set_fv_prop() (John Ferlan)
  - Coverity: Resolve NO_EFFECT - set_proc_rasd_params() (John Ferlan)
  - Coverity: Resolve DEADCODE - octets_from_ip() (John Ferlan)
  - Coverity: Resolve DEADCODE - get_hypervisor_enabled() (John Ferlan)
  - Coverity: Resolve DEADCODE - do_parse() (John Ferlan)
  - Coverity: Resolve CHECKED_RETURN - return_enum_rasds() (John Ferlan)
  - Coverity: Resolve CHECKED_RETURN - mem_rasd_to_vdev() (John Ferlan)
  - Coverity: Resolve CHECKED_RETURN - get_pools() (John Ferlan)
  - Coverity: Resolve CHECKED_RETURN - get_dev_from_pool (John Ferlan)
  - Coverity: Resolve CHECKED_RETURN - filter_by_pool() (John Ferlan)
  - Coverity: Resolve CHECKED_RETURN - _generic_infostore_open() (John
    Ferlan)
  - Coverity: Resolve BAD_COMPARE - ActivateFilter() (John Ferlan)
  - VSMS: tip error for invalid disk resource (Xu Wang)
- Fix license identification
- Add conditional restarting of the sfcb into %%post and %%postun,
  after proper registration/deregistration of the provider
* Mon Apr 15 2013 kkaempf@suse.com
- Update to 0.6.2
  * libxkutil: set domain->dype to unknown by default (Wenchao Xia)
  * register: Adjust the chatter output (John Ferlan)
  * DevicePool: Use the virConnectListAll interfaces (John Ferlan)
  * libxkutil: Use virConnectListAllDomains() to fetch domains (John Ferlan)
  * xmlgen: Only support script on bridge for xen domains (John Ferlan)
  * Remove empty newline at bottom (John Ferlan)
  * libvirt-cim.spec: Use systemctl for tog-pegasus restart (John Ferlan)
  * Makefile.am: Remove the $(top_srcdir) from subst command (John Ferlan)
  * migration: allow ssh based migration with non root's key file (Wenchao Xia)
  * misc_util: better way to read config (Wenchao Xia)
  * VSSD: report success if not all VS fail in enum (Wenchao Xia)
  * CSI: Move native CSI code together (Wenchao Xia)
  * CSI Discard libvirt event by default (Wenchao Xia)
  * device parsing, add debug print (Wenchao Xia)
  * DevicePool, reimplement get_diskpool_config with libvirt (Wenchao Xia)
  * CSI, add lock to protect shared data in lifecycle_thread (Wenchao Xia)
  * CSI, DevicePool, RASDIndication: fix debug print crash (Wenchao Xia)
  * do not deregister virt classes in yum upgrade (Wenchao Xia)
  * SDC: use property BootDevices instead of BootDevice (Wenchao Xia)
  * SDC: Fix spelling for property IsFullVirt (Wenchao Xia)
  * Remove property CreationClassName in some instance (Wenchao Xia)
  * fix id parsing with white space (Wenchao Xia)
  * Fix an incomplete substitution in Makefile (Klaus Kaempf)
  * distinguish running or inactive state (Wenchao Xia)
  * Fix possible memory leaks (Eduardo Lima (Etrunko))
  * Pool Refresh Patch2 (Gareth S. Bestor)
  * CSI: Only execute callback if indications are enabled (Eduardo Lima
    (Etrunko))
  * CSI: Fix log messages (Eduardo Lima (Etrunko))
  * CSI: Cleanup code (Eduardo Lima (Etrunko))
  * Plan9fs (aka 9pfs, VirtFS) support for QEMU/KVM environment (Deepak C
    Shetty)
* Mon Feb 11 2013 ohering@suse.de
- remove disabled shell code from specfile to fix rpmlint warning
* Fri Dec 28 2012 dvaleev@suse.com
- use macro for restart on update
* Thu Nov 29 2012 kkaempf@suse.com
- adapt to systemd usage in sblim-sfcb
* Tue Aug  7 2012 ohering@suse.de
- buildrequire xen-devel only on x86
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Thu Feb  9 2012 kkaempf@suse.com
- Update to 0.6.1
  * ACL: Use linked list helper for filter refs (Eduardo Lima (Etrunko))
  * CSI: Use list helper implementation (Eduardo Lima (Etrunko))
  * libxkutil: Linked list helper (Eduardo Lima (Etrunko))
  * FilterEntry: Accept protocol id string values (Eduardo Lima (Etrunko))
  * FilterEntry: Update action property (Eduardo Lima (Etrunko))
  * FilterList: Add 'Priority' property (Eduardo Lima (Etrunko))
  * FilterEntry: Change 'Priority' property type (Eduardo Lima (Etrunko))
  * Fix AppliedFilterList creation and deletion (Chip Vincent)
  * autoconfiscate.sh: Use proper command for revision count (Eduardo Lima (Etrunko))
  * libxkutil: Fix possible NULL dereferences (Eduardo Lima (Etrunko))
  * Fix possible use of unitialized variables (Eduardo Lima /Etrunko))
  * xml_parse_test: Fix invalid dereference (Eduardo Lima (Etrunko))
  * Fix possible memory leaks (Eduardo Lima (Etrunko))
  * Fix a problem with multi-arch (Daniel Veillard)
  * Remove compilation warnings (Eduardo Lima (Etrunko))
  * VirtualSystemManagementService: Remove dead code (Eduardo Lima (Etrunko))
- Update to 0.6.0
  * ComputerSystemIndication: Support libvirt domain events (Eduardo Lima (Etrunko))
  * Network QoS Patch2 (Gareth S. Bestor)
  * cpu cgroup patch 2 (Gareth S. Bestor)
  * Build: Make 'make distcheck' happy (Eduardo Lima (Etrunko))
  * Build: Remove tests subdirs from source (Eduardo Lima (Etrunko)
- Update to 0.5.15
  * Fix include path (Eduardo Lima (Etrunko))
  * xmlgen: Avoid double-free (Eduardo Lima (Etrunko))
  * Fix possible use of uninitialized variables (Eduardo Lima (Etrunko))
  * Fix misuse of signed variables (Eduardo Lima (Etrunko))
  * Avoid NULL dereferences in various providers (Eduardo Lima (Etrunko))
  * ACL: Plug leaks (Eduardo Lima (Etrunko))
  * device_parsing: Avoid NULL dereferences (Eduardo Lima (Etrunko))
  * pool_parsing: Avoid NULL dereferences (Eduardo Lima (Etrunko))
  * acl_parsing: Avoid NULL dereference (Eduardo Lima (Etrunko))
  * Avoid connection to libvirt if previous attempt fails (Eduardo Lima (Etrunko))
  * Fix qos bug in primordial Network/0 pool (Gareth S. Bestor)
  * Rename .hgignore -> .gitignore (Chip Vincent)
  * Update autoconfiscate.sh to use git (Chip Vincent)
  * Add network qos (bandwidth) support for KVM guests (Gareth Bestor)
  * /dev/null should not be passed as source dev for cdrom device. (Sharad Mishra)
  * Add support for libvirt CPU cgroup for active KVM guests (Gareth S. Bestor)
  * FilterEntry: Set HdrProtocolID8021 property (Eduardo Lima (Etrunko))
  * FilterEntry: Fix behavior of convert_ip_rule_to_instance (Eduardo Lima (Etrunko))
  * FilterEntry: Support for mask in CIDR notation (Eduardo Lima (Etrunko))
  * FilterEntry: Should be using srcipaddr instead of srcmacaddr (Eduardo Lima (Etrunko))
  * acl_parsing: Share code for icmp and icmp rule types (Eduardo Lima (Etrunko))
  * Pool names with space do not get parsed properly. (Sharad Mishra)
  * VirtualSystemManagementService: Avoid extra connection to libvirt (Eduardo Lima (Etrunko))
  * (#2) Fix the problem that libvirt-cim can't find cdrom device that do not have disk (Wayne Xia)
  * device_parsing: Small code cleanup (Eduardo Lima (Etrunko))
  * device_parsing: Use default values for vnc graphics device (Eduardo Lima (Etrunko))
  * ACL: Add KVM_FilterEntry class (Eduardo Lima (Etrunko))
  * Fix MOF download location - URL permanently changed (Chip Vincent)
  * Redirect stdout & stderr when run as out-of-process provider (Chip Vincent)
  * (#2) Return migration job status in CIM_ConcreteJob.ErrorCode (Sharad Mishra)
  * ACL: Add 'Action' property to KVM_{IPHeaders,Hdr8021}Filter (Eduardo Lima (Etrunko))
  * (#2) Workaround to fix race condition around libvirt init. (Sharad Mishra)
  * VirtualSystemManagementService: Fix yet another possible leak (Eduardo Lima (Etrunko))
  * VirtualSystemManagementService: Fixing potential null dereferences (Eduardo Lima (Etrunko))
  * device_parsing: Fixing potential leaks (Eduardo Lima (Etrunko))
  * Patches for Virt_SettingsDefineCapabilities: incorrect Default Value... (Gareth S. Bestor)
  * (#5) add sdl frame buffer support. (Wayne Xia)
  * (#5) made the graphic structure as union (Wayne Xia)
  * acl_parsing: Fixing potential leaks (Eduardo Lima (Etrunko))
  * Check to see if stream is non-null before closing. (Sharad Mishra)
  * Return object paths for newly created filter associations. (Chip Vincent)
  * New entry "poolid" was not getting DUPed. (Sharad Mishra)
  * Fix connection leak introduced in patch 1119. (Sharad Mishra)
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sat Sep 17 2011 kkaempf@suse.com
- Update to 0.5.14
  * Fix crash when creating ACL filter lists (Chip Vincent)
  * Remove has_vnc_passwd key from infostore (Eduardo Lima)
  * Set PoolID for CIM_DiskResourceAlloca... (Sharad Mishra)
  * libxkutil: More meaningful log message (Eduardo Lima)
  * Add source host and directory for netfs diskpool (Sharad Mishra)
  * Set PoolID for CIM_NetResourceAllocationSettingData (Sharad Mishra)
  * libxkutil: Handle vnc password when ret... (Eduardo Lima)
  * Conditionally compile ACL APIs (Chip Vincent)
  * SwitchService will show the nic connected to VSI... (Sharad Mishra)
  * Make libconfig requirement optional (Eduardo Lima)
  * libvirt-cim.spec: Use %%config(noreplace)... (Eduardo Lima)
  * Minor fix for MemoryPool.AllocationUnits (Chip Vincent)
  * Adjust FilterList.registration file permission (Chip Vincent)
- Update to 0.5.13
  * Add write support for FilterList (Chip Vincent)
  * Add read-only support (Eduardo Lima)
  * Fix MemoryPool.Reserved (Chip Vincent)
  * Check libvirt version before compiling ACL (Chip Vincent)
  * Fix AppliedFilterList Associators (Chip Vincent)
  * Libvirt dependency should be 0.6.3 (Chip Vincent)
  * Conditional build requirement for RPM package (Eduardo Lima)
  * Fill up NetworkName attribute (Eduardo Lima)
  * Add DCN ACL classes & providers (Chip Vincent)
  * Configure tweaks (Eduardo Lima)
  * Update RPM spec file to match Fedora (Eduardo Lima)
  * Migration was failing due to lost connection (Sharad Mishra)
  * Fix file permissions (Eduardo Lima)
  * Update .hgignore (Eduardo Lima)
  * Configure: Check for libuuid (Eduardo Lima)
  * Fix for VirtualSystemManagementService test (Chip Vincent)
  * Fix connection leaks (Sharad Mishra)
  * Ensure graphics devices have unique IDs (Chip Vincent)
  * Add support for StoragePool autostart (Sharad Mishra)
  * Add support for console/serial grahpics devices (Chip Vincent)
  * Add check to verify that sysname is not null (Sharad Mishra)
  * Added support for disk driver (Sharad Mishra)
  * Add VNC autoport support (Chip Vincent)
  * Add support for Pegasus OOP grouping (Chip Vincent)
  * Add SCCN and CCN for SwitchService (Sharad Mishra)
  * Fixing NullPointerException (Sharad Mishra)
  * Auto refresh StoragePools (Sharad Mishra)
  * Query switch to find its vsi capabilities (Sharad Mishra)
  * Set CreationClassName property in VSMS (Sharad Mishra)
  * Set/Reset VM autostart (Sharad Mishra)
  * Remove test for duplicate mac address (Sharad Mishra)
  * Add support for deactivation of disk caching (Sharad Mishra)
  * Add readonly property to disk (Sharad Mishra)
* Fri Jan 28 2011 kkaempf@novell.com
- Update to 0.5.12
  * Update indication providers to the std_indication interface change
    introduced in libcmpiutil f967d9432f31 (Chip Vincent)
  * Fix to support domain name with space (Sharad Mishra)
  * Patch to allow cdrom media change (Sharad Mishra)
  * Add domain UUID and timestamp to ComputerSystem and MigrationJob
    Indications (Chip Vincent)
  * Return profiles according to role (Chip Vincent)
  * Removing the code to fetch sblim instance (Sharad Mishra)
  * Update revision and force creation of INFO_STORE during install
    (Chip Vincent)
  * NetRASD enumeration to show VSI fields (Sharad Mishra)
  * Set default VM autostart value (Sharad Mishra)
  * Generating Deleted indication after Modified indication (Sharad
    Mishra)
  * Workaround for Pegasus ObjectPath issue. (Sharad Mishra)
  * Bypass cdrom check while defining VMs (Sharad Mishra)
  * Ensure AllocationUnits property populates the libvirt XML
    'capacity unit' AND 'allocation unit' so they are the same (Chip
    Vincent)
  * Use libvirt to get StorageVolume Path to set SV InstanceID (Sharad
    Mishra)
  * Update xml generation to support vepa (Sharad Mishra)
* Tue Nov 30 2010 kkaempf@novell.com
- update to 0.5.10
  Fix RHEL5 build
* Thu Sep 16 2010 kkaempf@novell.com
- Fix RH/Fedora build
* Wed Mar  3 2010 jfehlig@novell.com
- Fix ElementAllocatedFromPool association
  bnc#584708
  1022-eafp.patch
* Tue Dec  8 2009 jfehlig@novell.com
- Xen version >= 3.3.0 doesn't accept system in the migration URI
  bnc#572034
  1020-xen-mig-uri.patch
* Thu Dec  3 2009 jfehlig@novell.com
- Updated to version 0.5.8, FATE#307241
  - IPv6 support:
    Defining guests with IPv6 VNC addresses
    Representing VNC graphics devices configured with IPv6
    addresses
  - Allow user to specify ACPI, PAE, and APIC support for a given
    guest
  - Many improvements and bug fixes
* Tue Oct 27 2009 jfehlig@novell.com
- Updated to version 0.5.7, FATE#307241
  - Image creation support
  - Resource indication provider
  - Many improvements and bug fixes
* Tue Sep 22 2009 jfehlig@novell.com
- Fix memory leak and general cleanup of _get_rasds() function
  9xx-get-rasd-cleanup.patch
  bnc#540497
* Mon Aug 31 2009 aj@suse.de
- Remove eth-device.patch, it does not apply anymore to changed
  code.
- Remove commented out and non-existing patch3 from spec file.
* Mon Aug 31 2009 aj@suse.de
- Don't install schema/ElementConformsToProfile.registration twice
  to same path to fix build.
* Fri Aug  7 2009 jfehlig@novell.com
- Updated to version 0.5.6
  - Storage pool support
  - Network pool support
  - Update to CIM schema 2.21
* Tue Dec  9 2008 jfehlig@novell.com
- Add support for clock offset.  Required for Windows guests.
  bnc#457706
* Mon Dec  8 2008 jfehlig@novell.com
- Do not default vnclisten
  bnc#456912
* Thu Dec  4 2008 jfehlig@novell.com
- Fix _diskpool_is_member() to return correct pool
  bnc#456587
- Return job on snapshot create/apply operations
  bnc#456630
* Wed Dec  3 2008 jfehlig@novell.com
- Catch unimplemented sentinel of GetMaxVcpus
  bnc#455803
* Mon Nov 17 2008 jfehlig@novell.com
- Fix malformed domain XML created by libvirt-cim.
  bnc#442853
* Fri Nov 14 2008 jfehlig@novell.com
- Do not default network source if none is provided in device xml
  bnc#443988
* Fri Nov  7 2008 jfehlig@novell.com
- Preserve domain configuration on redefine operations.  Related
  to bnc#431758 and bnc#437388
* Wed Nov  5 2008 jfehlig@novell.com
- Do not register ConsoleRedirectionService providers  bnc#441029
* Wed Nov  5 2008 jfehlig@novell.com
- Remove netpool-suse.patch  bnc#441633
* Tue Oct 28 2008 jfehlig@novell.com
- bnc#431758
  + Added upstream patches to fix vcpu count on running domains
  + 'ethernet' is a valid net device type - eth-device.patch
* Mon Oct 20 2008 jfehlig@novell.com
- Added upstream patches for additional LXC support - bnc#433881
- Removed bogus xen-devel BuildRequires
* Fri Oct 10 2008 jfehlig@novell.com
- Updated to release 0.5.2
  + LXC support
  + ServiceAffectsElement
  + RedirectionService
  + Integration with SBLIM providers
* Fri Oct  3 2008 jfehlig@novell.com
- Another snapshot of libvirt-cim head
  + more LXC support
  + ServiceAffectsElement association
* Fri Oct  3 2008 dpmerrill@novell.com
- Added LibvirtVersion to Xen_VirtualSystemManagementService
* Wed Sep 17 2008 jfehlig@novell.com
- Another snapshot of libvirt-cim head.
- Do not use libvirt network API at this time
  netpool-suse.patch
* Sat Aug  9 2008 jfehlig@novell.com
- Another snapshot of libvirt-cim head.
  + Fix SnapshotService
  + Package directory /etc/libvirt/cim
* Tue Aug  5 2008 jfehlig@novell.com
- Another snapshot of libvirt-cim head.  Version is 0.5.1 instead
  of incorrect 0.6 pre-release as previously noted.
* Mon Jul 28 2008 jfehlig@novell.com
- Updated to libvirt-cim head, pre-release of 0.6
* Fri Jul 18 2008 jfehlig@novell.com
- Provides/Obsoletes xen-cim-cmpi  bnc#403156
- Remove ExclusiveArch restriction
* Thu Jul 17 2008 jfehlig@novell.com
- Change "PreReq: sblim-sfcb" to "Requires: cim-server", allowing
  cimom neutral provider package.
* Thu Jun 26 2008 jfehlig@novell.com
- Updated to official libvirt-cim 0.4 release
* Mon May 19 2008 jfehlig@novell.com
- Change sblim-sfcb from Requires to PreReq.  bnc#391837
- Fix some packaging issues addressed by previous change
* Sun May 18 2008 aj@suse.de
- Add rpmlintrc file for modules.
- Package some extra files.
- Own lib directory.
* Fri May 16 2008 jfehlig@novell.com
- Remove inclusion of base schema and use cim-schema package instead
- Add provider schema to /root/interop namespace
* Tue May  6 2008 jfehlig@novell.com
- Fix handling of directories in install_base_schema.sh allowing
  the schema to be properly imported into sfcb.
* Thu May  1 2008 jfehlig@novell.com
- Initial creation of package
